[−][src]Enum embedded_error::mci::SetupError
Enumeration used when setting up the device especially when installing MMC
Variants (Non-exhaustive)
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Could not set bus width
Could not set to high speed
Could not check if it is a high speed device